@@ -9,6 +9,14 @@
         <translation>Attribute</translation>
     </message>
 </context>
+<context>
+    <name>CacheProvider</name>
+    <message>
+        <location filename="../src/cacheprovider.cpp" line="377"/>
+        <source>&amp;Cache Provider</source>
+        <translation>&amp;Cache-Datenquelle</translation>
+    </message>
+</context>
 <context>
     <name>CacheWindow</name>
     <message>
@@ -73,6 +81,46 @@
         <translation>Im Browser öffnen</translation>
     </message>
 </context>
+<context>
+    <name>GcBrowser</name>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="97"/>
+        <source>No valid login specified, cache positions will be inaccurate!</source>
+        <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="198"/>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="249"/>
+        <source>Login failed!</source>
+        <translation>Einloggen fehlgeschlagen!</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="355"/>
+        <source>Unable to determine cache id!</source>
+        <translation>Cache-ID nicht feststellbar!</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="383"/>
+        <source>Unable to determine cache guid!</source>
+        <translation>Cache-Guid nicht feststellbar!</translation>
+    </message>
+    <message>
+        <source>Plugin:</source>
+        <translation type="obsolete">Erweiterung:</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="obsolete">Benutzername</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="obsolete">Passwort</translation>
+    </message>
+</context>
 <context>
     <name>GcDialog</name>
     <message>
@@ -91,74 +139,120 @@
 <context>
     <name>GcLive</name>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="96"/>
         <source>No valid login specified, cache positions will be inaccurate!</source>
-        <translation>Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
+        <translation type="obsolete">Kein gültiger Login angegeben, Cache-Positionen werden ungenau sein!</translation>
     </message>
     <message>
         <source>Login successful!</source>
         <translation type="obsolete">Einloggen erfolgreich!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="181"/>
         <source>Error</source>
-        <translation>Fehler</translation>
+        <translation type="obsolete">Fehler</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="232"/>
         <source>Login failed!</source>
-        <translation>Einloggen fehlgeschlagen!</translation>
+        <translation type="obsolete">Einloggen fehlgeschlagen!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="336"/>
         <source>Unable to determine cache id!</source>
-        <translation>Cache-ID nicht feststellbar!</translation>
+        <translation type="obsolete">Cache-ID nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="364"/>
         <source>Unable to determine cache guid!</source>
-        <translation>Cache-Guid nicht feststellbar!</translation>
+        <translation type="obsolete">Cache-Guid nicht feststellbar!</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="401"/>
-        <source>GcLive</source>
-        <translation></translation>
+        <source>Plugin:</source>
+        <translation type="obsolete">Erweiterung:</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="408"/>
         <source>Username</source>
-        <translation>Benutzername</translation>
+        <translation type="obsolete">Benutzername</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gclive.cpp" line="413"/>
         <source>Password</source>
-        <translation>Passwort</translation>
+        <translation type="obsolete">Passwort</translation>
     </message>
 </context>
 <context>
     <name>GcParser</name>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gcparser.cpp" line="308"/>
-        <location filename="../plugins/cacheprovider/gclive/gcparser.cpp" line="316"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="308"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="316"/>
         <source>Too many caches</source>
         <translation>Zu viele Caches</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gcparser.cpp" line="309"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="309"/>
         <source>No caches in this area</source>
         <translation>Keine Caches in dieser Gegend</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gcparser.cpp" line="379"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="379"/>
         <source>Error downloading caches</source>
         <translation>Fehler beim Laden der Caches</translation>
     </message>
     <message>
-        <location filename="../plugins/cacheprovider/gclive/gcparser.cpp" line="449"/>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcparser.cpp" line="449"/>
         <source>Error downloading cache info</source>
         <translation>Fehler beim Download der Cache-Info</translation>
     </message>
 </context>
+<context>
+    <name>Gpx</name>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="72"/>
+        <source>File %1 does not contain any geocaches</source>
+        <translation>Die Datei %1 enthält keine Geocaches</translation>
+    </message>
+    <message>
+        <source>Open Pocket Query (GPX or ZIP)</source>
+        <translation type="obsolete">Pocket-Query öffnen (GPX oder ZIP)</translation>
+    </message>
+    <message>
+        <source>Pocket Queries (*.gpx *.zip)</source>
+        <translation type="obsolete">Pocket-Queries (*.gox *.zip)</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="101"/>
+        <source>Open Pocket Query (GPX, LOC or ZIP)</source>
+        <translation>Pocket-Query öffnen (GPX, LOC oder ZIP)</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="102"/>
+        <source>Pocket Queries (*.gpx *.loc *.zip)</source>
+        <translation>Pocket-Queries (*.gpx *.loc *.zip)</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="111"/>
+        <source>File %1 not found</source>
+        <translation>Datei %1 nicht gefunden</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="164"/>
+        <source>No caches in this area</source>
+        <translation>Keine Caches in dieser Gegend</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="181"/>
+        <source>Unable to get cache info</source>
+        <translation>Kann Cache-Info nicht laden</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="197"/>
+        <source>Unable to get cache detail</source>
+        <translation>Kann Cache-Details nicht laden</translation>
+    </message>
+    <message>
+        <source>Plugin:</source>
+        <translation type="obsolete">Erweiterung:</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="obsolete">Benutzername</translation>
+    </message>
+</context>
 <context>
     <name>HintDialog</name>
     <message>
@@ -177,7 +271,7 @@
 <context>
     <name>LogWidget</name>
     <message>
-        <location filename="../src/logwindow.cpp" line="66"/>
+        <location filename="../src/logwindow.cpp" line="20"/>
         <source>by</source>
         <translation>von</translation>
     </message>
@@ -185,7 +279,7 @@
 <context>
     <name>LogWindow</name>
     <message>
-        <location filename="../src/logwindow.cpp" line="82"/>
+        <location filename="../src/logwindow.cpp" line="36"/>
         <source>Logs</source>
         <translation>Logs</translation>
     </message>
@@ -197,9 +291,8 @@
         <translation type="obsolete">&amp;Datei</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="23"/>
         <source>E&amp;xit</source>
-        <translation>B&amp;eenden</translation>
+        <translation type="obsolete">B&amp;eenden</translation>
     </message>
     <message>
         <source>&amp;Map</source>
@@ -214,45 +307,45 @@
         <translation type="obsolete">&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="26"/>
+        <location filename="../src/mainwindow.cpp" line="23"/>
         <source>&amp;Settings</source>
         <translation>&amp;Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="27"/>
+        <location filename="../src/mainwindow.cpp" line="22"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="38"/>
+        <location filename="../src/mainwindow.cpp" line="37"/>
         <source>About CacheMe</source>
         <translation>Über CacheMe</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="39"/>
-        <location filename="../src/mainwindow.cpp" line="53"/>
+        <location filename="../src/mainwindow.cpp" line="38"/>
+        <location filename="../src/mainwindow.cpp" line="52"/>
         <source>CacheMe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="39"/>
+        <location filename="../src/mainwindow.cpp" line="38"/>
         <source>Version</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="40"/>
+        <location filename="../src/mainwindow.cpp" line="39"/>
         <source>Build date:</source>
         <translation>Erstellungsdatum:</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="41"/>
+        <location filename="../src/mainwindow.cpp" line="40"/>
         <source>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;</source>
         <oldsource>(c) 2011 by Till Harbaum &lt;till@harbaum.org&gt;
 </oldsource>
         <translation>(c) 2011 von Till Harbaum &lt;till@harbaum.org&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="42"/>
+        <location filename="../src/mainwindow.cpp" line="41"/>
         <source>CacheMe is an online geocaching application.</source>
         <translation>CacheMe ist eine Online-Geocaching-Anwendung.</translation>
     </message>
@@ -310,6 +403,11 @@
         <source>Opening &quot;%1&quot; in browser ...</source>
         <translation type="obsolete">Öffne &quot;%1&quot; im Browser ...</translation>
     </message>
+    <message>
+        <location filename="../src/mapwidget.cpp" line="305"/>
+        <source>Displayed cache data is %1 weeks old!</source>
+        <translation>Angezeigte Cache-Daten sind %1 Wochen alt!</translation>
+    </message>
 </context>
 <context>
     <name>NavigationWindow</name>
@@ -402,7 +500,7 @@
         <translation>Gelegt von</translation>
     </message>
     <message>
-        <location filename="../src/mapbubble.cpp" line="269"/>
+        <location filename="../src/mapbubble.cpp" line="271"/>
         <source>Container</source>
         <translation>Behälter</translation>
     </message>
@@ -411,63 +509,63 @@
         <translation type="obsolete">Behältergröße</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="232"/>
+        <location filename="../src/cache.cpp" line="236"/>
         <source>Found it</source>
         <translation>Gefunden</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="233"/>
+        <location filename="../src/cache.cpp" line="237"/>
         <source>Didn&apos;t find it</source>
         <translation>Nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="234"/>
+        <location filename="../src/cache.cpp" line="238"/>
         <source>Owner Maintenance</source>
         <translation>Wartung durch Besitzer</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="235"/>
+        <location filename="../src/cache.cpp" line="239"/>
         <source>Write Note</source>
         <translation>Notiz geschrieben</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="236"/>
+        <location filename="../src/cache.cpp" line="240"/>
         <source>Post Reviewer Note</source>
         <translation>Gutachter-Notiz</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="237"/>
+        <location filename="../src/cache.cpp" line="241"/>
         <source>Enable Listing</source>
         <translation>Eingestellt</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="238"/>
+        <location filename="../src/cache.cpp" line="242"/>
         <source>Publish Listing</source>
         <translation>Veröffentlicht</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="239"/>
+        <location filename="../src/cache.cpp" line="243"/>
         <source>Will Attend</source>
         <translation>Werde teilnehmen</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="240"/>
+        <location filename="../src/cache.cpp" line="244"/>
         <source>Attended</source>
         <translation>Teilgenommen</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="241"/>
+        <location filename="../src/cache.cpp" line="245"/>
         <source>Webcam Photo taken</source>
         <translation>Webcam-Foto gemacht</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="242"/>
+        <location filename="../src/cache.cpp" line="246"/>
         <source>Temporarily Disable Listing</source>
         <translation>Zeitweilig deaktiviert</translation>
     </message>
     <message>
         <location filename="../src/cache.cpp" line="97"/>
-        <location filename="../src/cache.cpp" line="243"/>
+        <location filename="../src/cache.cpp" line="247"/>
         <source>Needs Maintenance</source>
         <translation>Benötigt Wartung</translation>
     </message>
@@ -788,7 +886,7 @@
     </message>
     <message>
         <location filename="../src/cache.cpp" line="79"/>
-        <source>Motorcacles Not Allowed</source>
+        <source>Motorcycles Not Allowed</source>
         <translation>Keine Motorräder erlaubt</translation>
     </message>
     <message>
@@ -1044,78 +1142,159 @@
         <translation>&lt;nicht unbekannt&gt;</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="244"/>
+        <location filename="../src/cache.cpp" line="248"/>
         <source>Update Coordinates</source>
         <translation>Koordinaten aktualisiert</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="245"/>
+        <location filename="../src/cache.cpp" line="249"/>
         <source>Unarchive</source>
         <translation>Dearchiviert</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="246"/>
+        <location filename="../src/cache.cpp" line="250"/>
         <source>Needs Archived</source>
         <translation>Sollte archiviert werden</translation>
     </message>
     <message>
-        <location filename="../src/cache.cpp" line="247"/>
+        <location filename="../src/cache.cpp" line="251"/>
         <source>Archive</source>
         <translation>Archiviert</translation>
     </message>
     <message>
         <location filename="../src/cache.cpp" line="133"/>
-        <location filename="../src/cache.cpp" line="248"/>
+        <location filename="../src/cache.cpp" line="252"/>
         <source>&lt;unknown&gt;</source>
         <translation>&lt;unbekannt&gt;</translation>
     </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gcbrowser/gcbrowser.cpp" line="166"/>
+        <source>GPL version 2
+Copyright 2011 by Till Harbaum
+QSgml parts Copyright 2010 by Andreas Lehmann</source>
+        <translation>GPL version 2
+Copyright 2011 durch Till Harbaum
+QSgml-Teile Copyright 2010 durch Andreas Lehmann</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpx.cpp" line="45"/>
+        <source>GPL version 2
+Copyright 2011 by Till Harbaum
+Quazip parts Copyright 2005 by Sergey A. Tachenov</source>
+        <translation>GPL versoin 2
+Copyright 2011 durch Till Harbaum
+Quazip-Teile Copyright 2005 durch Sergey A. Tachenov</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="26"/>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="42"/>
+        <source>Parse error at line %1, column %2:
+%3</source>
+        <translation>Lesefehler in Zeile %1, Spalte %2:
+%3</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="69"/>
+        <source>Cannot open file %1: Code %2</source>
+        <translation>Kann datei %1 nicht öffnen: Code %2</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="86"/>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="145"/>
+        <source>Cannot open file %1 for reading:
+%2</source>
+        <translation>Kann Datei %1 nicht zum Lesen öffnen:
+%2</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="124"/>
+        <source>Zip error in %1: Code %2</source>
+        <translation>Zip-Fehler in %1: Code %2</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="139"/>
+        <source>File is a waypoint file</source>
+        <translation>Datei ist eine Wegpunkt-Datei</translation>
+    </message>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/gpxfileparser.cpp" line="159"/>
+        <source>Unsupported file type: %1</source>
+        <translation>Nicht unterstützter Dateityp: %1</translation>
+    </message>
+    <message>
+        <source>Unsupported file type: %2</source>
+        <translation type="obsolete">Nicht unterstützter Dateityp: %2</translation>
+    </message>
+</context>
+<context>
+    <name>QuaZipFile</name>
+    <message>
+        <location filename="../plugins/cacheprovider/gpx/quazip-0.3/quazip/quazipfile.cpp" line="141"/>
+        <source>ZIP/UNZIP API error %1</source>
+        <translation>ZIP/UNZIP API-Fehler %1</translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="34"/>
+        <location filename="../src/settingsdialog.cpp" line="39"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="47"/>
+        <location filename="../src/settingsdialog.cpp" line="52"/>
         <source>Map</source>
         <translation>Karte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="51"/>
+        <location filename="../src/settingsdialog.cpp" line="56"/>
         <source>Street Map</source>
         <translation>Straßenkarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="51"/>
+        <location filename="../src/settingsdialog.cpp" line="56"/>
         <source>Satellite Map Day</source>
         <translation>Satellitenkarte Tag</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="52"/>
+        <location filename="../src/settingsdialog.cpp" line="57"/>
         <source>Satellite Map Night</source>
         <translation>Satellitenkarte Nacht</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="52"/>
+        <location filename="../src/settingsdialog.cpp" line="57"/>
         <source>Terrain Map</source>
         <translation>Geländekarte</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="55"/>
+        <location filename="../src/settingsdialog.cpp" line="60"/>
         <source>Map type</source>
         <translation>Kartentyp</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="71"/>
+        <location filename="../src/settingsdialog.cpp" line="76"/>
         <source>Map service</source>
         <translation>Kartendienst</translation>
     </message>
     <message>
-        <location filename="../src/settingsdialog.cpp" line="83"/>
+        <location filename="../src/settingsdialog.cpp" line="88"/>
         <source>A change of the map service takes effect after restart.</source>
         <translation>Ein Wechsel des Kartendienstes wird erst nach einem Neustart aktiv.</translation>
     </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="101"/>
+        <source>Geocaching.com account</source>
+        <translation>Geocaching.com-Zugang</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="106"/>
+        <source>Username</source>
+        <translation>Benutzername</translation>
+    </message>
+    <message>
+        <location filename="../src/settingsdialog.cpp" line="111"/>
+        <source>Password</source>
+        <translation>Passwort</translation>
+    </message>
 </context>
 </TS>
