@@ -58,6 +58,7 @@ class Log {
 
     Type();
     void set(Type::Id);
+    bool is(Type::Id) const;
     QString iconFile() const;
     QString toString() const;
 
@@ -224,18 +225,26 @@ class Cache : public QLandmark {
 
 class CacheList : QList<Cache> {
  public:
+  CacheList();
   CacheList(const QString &);
   ~CacheList();
   void append(Cache);
   int size() const;
   Cache at(int);
+  void setName(const QString &);
   QString name();
   QList<Cache>::const_iterator begin() const;
   QList<Cache>::const_iterator end() const;
+  QList<Cache>::const_iterator;
+  QList<Cache>::iterator begin();
+  QList<Cache>::iterator end();
   void clear();
+  void setDate(const QDate &);
+  QDate date() const;
 
  private:
   QString m_name;
+  QDate m_date;
 };
 
 #endif // CACHE_H
