@@ -1,8 +1,7 @@
 #ifndef CACHEPROVIDERPLUGIN_H
 #define CACHEPROVIDERPLUGIN_H
 
-#include <QNetworkReply>
-#include <QMenu>
+#include <QDialog>
 #include <QVBoxLayout>
 #include <QGeoBoundingBox>
 QTM_USE_NAMESPACE
@@ -13,17 +12,18 @@ class CacheProvider;
 class CacheProviderPlugin {
 
  public:
-  virtual void init() = 0;
   virtual QString name() = 0;
+  virtual QString license() = 0;
+  virtual bool canBeDefault() = 0;
+  virtual QObject *object() = 0;
+
+  virtual void init(QWidget *) = 0;
+  virtual void createConfig(QDialog *, QVBoxLayout*) = 0;
+
   virtual bool busy() = 0;
   virtual void processRequestOverview(const QGeoBoundingBox &) = 0;
   virtual void processRequestInfo(const QString &) = 0;
   virtual void processRequestDetail(const QString &) = 0;
-  virtual void createConfig(QDialog *, QVBoxLayout*) = 0;
-  virtual QObject *getObject() = 0;
-
-  public slots:
-  virtual void replyFinished(QNetworkReply*) = 0;
 };
 
 Q_DECLARE_INTERFACE(CacheProviderPlugin,
