@@ -8,12 +8,16 @@
 #include <QPainter>
 #include <QKeyEvent>
 #include <QPushButton>
-#include <QDesktopServices>
+#include <QFontInfo>
 
 #include "htmlview.h"
 #include "cachewindow.h"
 #include "descriptionwindow.h"
 #include "navigationwindow.h"
+#include "logwindow.h"
+#include "attributewindow.h"
+#include "iconlabel.h"
+
 #include "swapbox.h"
 
 class HintWindow : public CustomWindow {
@@ -31,105 +35,6 @@ void CacheWindow::showHint() {
   hintWindow->show();
 }
 
-// the star widget consists of 5 stars used to display ratings
-class StarWidget : public QLabel {
-public:
-  StarWidget(IconLoader *loader, const qreal rating, 
-	     QWidget *parent = 0) : QLabel(parent) {
-    int size = 2*font().pointSize();
-    int rating2 = (2*rating)+0.5;
-
-    // load the required pixmaps
-    QPixmap *starPix = loader->load("star", size);
-    QPixmap *starLightPix = loader->load("star_light", size);
-
-    // build the "half" pixmap if required
-    QPixmap *starHalfPix = NULL;
-    if(rating2 & 1) {
-      starHalfPix = new QPixmap(*starPix);
-      QPainter halfPainter(starHalfPix);
-      const QRectF half(size/2, 0, 
-			size/2, loader->size());
-      halfPainter.drawPixmap(half, *starLightPix, half);
-    }
-
-    // assemble pixmap and draw all five stars
-    QPixmap pixmap(5*size, size);
-    pixmap.fill(Qt::transparent);
-
-    QPainter painter(&pixmap);
-    QPixmap *star;
-    int i;
-    for(i=0;i<5;i++) {
-      if(rating2 < 2*(i+1)-1)    star = starLightPix;
-      else if(rating2 < 2*(i+1)) star = starHalfPix;
-      else                       star = starPix;
-      
-      painter.drawPixmap(i*size, 0, *star);
-    }
-
-    // and finally place the pixmap in the label
-    setPixmap(pixmap);
-  }
-};
-
-class RatingWidget : public QWidget {
-public:
-  RatingWidget(IconLoader *loader, 
-	       const QString &title, const qreal rating, 
-	       QWidget *parent = 0) : QWidget(parent) {
-    
-    QHBoxLayout *layout = new QHBoxLayout;
-    layout->setContentsMargins(0,0,0,0);
-    layout->addWidget(new QLabel(title + ":"));
-    layout->addWidget(new StarWidget(loader, rating), 0, Qt::AlignRight);
-    
-    setLayout(layout);
-  }
-};
-
-class ContainerWidget : public QWidget {
-public:
-  ContainerWidget(IconLoader *loader, 
-		  const QString &title, const Container container, 
-		  QWidget *parent = 0) : QWidget(parent) {
-    
-    QHBoxLayout *layout = new QHBoxLayout;
-    layout->setContentsMargins(0,0,0,0);
-    layout->addWidget(new QLabel(title + ":"));
-
-    QLabel *label = new QLabel();
-    QFont font = label->font();
-    label->setPixmap(*loader->load(container, 2*font.pointSize()));
-    layout->addWidget(label, 0, Qt::AlignRight);
-    
-    setLayout(layout);
-  }
-};
-
-class IconWidget : public QLabel {
-public:
-  IconWidget(QPixmap *pix, QWidget *parent = 0) : QLabel(parent) {
-    setPixmap(*pix);
-  };
-    
-  IconWidget(IconLoader *loader, const Cache &cache, int size = 0,
-	     QWidget *parent = 0)  : QLabel(parent) {
-    setPixmap(*loader->load(cache, size));
-  };
-};
-
-class Label : public QLabel {
-public:
-  Label(const QString &text, bool bold = false, qreal fontScale = 1.0,
-	QWidget *parent = 0) : QLabel(text, parent) {
-    QFont font = this->font();
-    font.setPointSize(fontScale*font.pointSize());
-    if(bold) font.setWeight(QFont::Bold);
-    this->setFont(font);
-  };
-};
-
 #define HACK
 
 // a qpushbutton with a small icon on the right
@@ -199,10 +104,6 @@ private:
   QPixmap *m_pixmap;
 };
 
-void CacheWindow::openCacheUrl() {
-  QDesktopServices::openUrl(m_cache.url());
-}
-
 CacheWindow::CacheWindow(const Cache &cache, 
 	 LocationProvider *locationProvider, QWidget *parent) : 
   CustomWindow("CacheWindow", parent),  m_cache(cache), m_iconLoader(24),
@@ -210,7 +111,7 @@ CacheWindow::CacheWindow(const Cache &cache,
 
   setWindowTitle(cache.name());
 
-  //  qDebug() << __FUNCTION__ << cache;
+  qDebug() << __FUNCTION__ << cache;
 
   QWidget *vbox = new QWidget;
   QVBoxLayout *layout = new QVBoxLayout;
@@ -222,18 +123,8 @@ CacheWindow::CacheWindow(const Cache &cache,
   // ---------- general info on top -------------
   
   // ------------- title with icon -------------
-  QWidget *hbox = new QWidget;
-  QHBoxLayout *hlayout = new QHBoxLayout;
-  hbox->setLayout(hlayout);
-
-  Label *label = new Label("<h2>"+cache.description()+"</h2>");
-  hlayout->addWidget(new IconWidget(&m_iconLoader, cache, 
-				    3*label->font().pointSize()));
-  label->setWordWrap(true);
-  // hcenter sometimes causes broken word wrap
-  hlayout->addWidget(label, 1 /*, Qt::AlignHCenter*/ );
-
-  layout->addWidget(hbox);
+  layout->addWidget(new IconLabel(&m_iconLoader, cache, 
+				  cache.description(), 1.5));
 
   // if there's a short description, then use a swapbox to place
   // the description in landscape in the left window half
@@ -291,12 +182,22 @@ CacheWindow::CacheWindow(const Cache &cache,
     layout->addWidget(button);
   }
 
-  // ------------- button to open web link -------------
-  if(cache.url().isValid()) {
-    Button *button = new Button(tr("Open in browser"));
-    button->addIcon(&m_iconLoader, "browser");    
+  // ------------- button to display logs -------------
+  if(cache.logs().size()) {
+    Button *button = new Button(tr("Logs"));
+    button->addIcon(&m_iconLoader, "new_window");    
 
-    connect(button, SIGNAL(clicked()), this, SLOT(openCacheUrl()));
+    connect(button, SIGNAL(clicked()), this, SLOT(showLogs()));
+
+    layout->addWidget(button);
+  }
+
+  // ------------- button to display attributes -------------
+  if(cache.attributes().size()) {
+    Button *button = new Button(tr("Attributes"));
+    button->addIcon(&m_iconLoader, "new_window");    
+
+    connect(button, SIGNAL(clicked()), this, SLOT(showAttributes()));
 
     layout->addWidget(button);
   }
@@ -311,8 +212,6 @@ CacheWindow::~CacheWindow() {
 }
 
 void CacheWindow::showDescription() {
-  qDebug() << __FUNCTION__ << m_cache.description();
-
   DescriptionWindow *descriptionWindow = 
     new DescriptionWindow(m_cache, this);
 
@@ -320,10 +219,22 @@ void CacheWindow::showDescription() {
 }
 
 void CacheWindow::showNavigation() {
-  qDebug() << __FUNCTION__ << m_cache.description();
-
   NavigationWindow *navigationWindow = 
     new NavigationWindow(m_cache, m_locationProvider, this);
 
   navigationWindow->show();
 }
+
+void CacheWindow::showLogs() {
+  LogWindow *logWindow = 
+    new LogWindow(m_cache.logs(), this);
+
+  logWindow->show();
+}
+
+void CacheWindow::showAttributes() {
+  AttributeWindow *attributeWindow = 
+    new AttributeWindow(m_cache.attributes(), this);
+
+  attributeWindow->show();
+}
