@@ -18,7 +18,8 @@ class CacheWindow : public CustomWindow {
   void showDescription();
   void showNavigation();
   void showHint();
-  void openCacheUrl();
+  void showLogs();
+  void showAttributes();
 
  private:
   Cache m_cache;
