@@ -8,7 +8,10 @@
 #include <QPixmap>
 #include <QSvgRenderer>
 #include <QGeoPositionInfo>
+
+#ifndef Q_WS_WIN
 #include <QCompass>
+#endif
 
 QTM_USE_NAMESPACE
 
@@ -26,7 +29,9 @@ class Compass : public QWidget {
 
  public slots:
   void setPosition(const QGeoPositionInfo &);
+#ifndef Q_WS_WIN
   void setPosition(const QCompassReading *);
+#endif
   void timerExpired();
 
  private:
