@@ -18,6 +18,9 @@ public:
   QPixmap *load(const Cache &, int = 0);
   QPixmap *load(const Container &, int = 0);
   int size() const;
+  QWidget *newWidget(const QString &, int = 0);
+  QWidget *newWidget(const QStringList &, int = 0);
+  QWidget *newWidget(const Cache &, int = 0);
 
 private:
   QSvgRenderer *m_renderer;
@@ -29,7 +32,6 @@ private:
     ~Pixmap();
     QPixmap *pixmap();
     bool is(const QString &);
-    QString assembleFilename(const QStringList &);
     bool load(QSvgRenderer *, const QString &);
 
   private:
