@@ -3,6 +3,10 @@
 
 #include <QGeoPositionInfoSource>
 
+#ifndef Q_WS_WIN
+#include <QCompass>
+#endif
+
 QTM_USE_NAMESPACE
 
 class LocationProvider : public QObject {
@@ -14,12 +18,21 @@ class LocationProvider : public QObject {
 
  private slots:
   void positionHasBeenUpdated(const QGeoPositionInfo &);
+#ifndef Q_WS_WIN
+  void checkCompassReading();
+#endif
 
  signals:
   void positionUpdated(const QGeoPositionInfo &);
+#ifndef Q_WS_WIN
+  void positionUpdated(const QCompassReading *);
+#endif
 
  private:
   QGeoPositionInfoSource *m_location;
+#ifndef Q_WS_WIN
+  QCompass *m_compass;
+#endif
 };
 
 #endif // LOCATIONPROVIDER_H
