@@ -1,6 +1,5 @@
 #include <QApplication>
 #include <QTranslator>
-#include <QDir>
 #include <QLocale>
 #include <QDebug>
 
@@ -16,16 +15,14 @@ int main(int argc, char **argv) {
 #ifdef LIBDIR
   // make sure the geoservice plugins in /usr/lib/cacheme/plugins
   // can be found
-  app.addLibraryPath(QDir::toNativeSeparators(LIBDIR) + 
-		     QDir::separator() + "plugins");
+  app.addLibraryPath(QString(LIBDIR) + "/plugins");
 #endif  
 
 #ifdef DATADIR
   // try to load translation, first from local, then from DATADIR
   if(!translator.load(QString(APPNAME) + "_" + locale))
     translator.load(QString(APPNAME) + "_" + locale, 
-		    QDir::toNativeSeparators(DATADIR) + 
-		    QDir::separator() + "lang");
+		    QString(DATADIR) + "/lang");
 #else
   translator.load(QString(APPNAME) + "_" + locale);
 #endif
