@@ -19,12 +19,11 @@
 #endif
 
 void MainWindow::createMenu() {
-#if !defined(Q_WS_MAEMO_5) && !defined(Q_OS_SYMBIAN)
-  addMenuEntry(tr("E&xit"), this, SLOT(close()));
-#endif
-  
-  addMenuEntry(tr("&Settings"), this, SLOT(settingsdialog()));
   addMenuEntry(tr("&About"), this, SLOT(about()));
+  addMenuEntry(tr("&Settings"), this, SLOT(settingsdialog()));
+
+  /* create a submenu for the plugin selection */  
+  m_cacheProvider->createMenu(menuBar());
 }
 
 void MainWindow::settingsdialog() {
@@ -48,7 +47,7 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   CustomWindow("MainWindow", parent), m_locationProvider(locationProvider) {
 
   qDebug() << __FUNCTION__;
-  m_cacheProvider = new CacheProvider();
+  m_cacheProvider = new CacheProvider(this);
 
   setWindowTitle(tr("CacheMe"));
 
@@ -93,7 +92,7 @@ MainWindow::MainWindow(LocationProvider *locationProvider, QWidget *parent) :
   QObject::connect(this->m_cacheProvider, SIGNAL(replyError(const QString &)), 
 		   this, SLOT(displayError(const QString &)));
 
-  QObject::connect(this->m_cacheProvider, SIGNAL(settingsChanged()),
+  QObject::connect(this->m_cacheProvider, SIGNAL(reload()),
 		   this, SLOT(reloadCaches()));
 
   QObject::connect(this->m_cacheProvider, SIGNAL(notifyBusy(bool)),
