@@ -31,7 +31,17 @@ void MapBanner::flush(MapBannerEntry *entry) {
 void MapBanner::paint(QPainter *painter) {
   // for some very odd reason, the list gets deleted when using
   // the "foreach" operator instead
+  int j;
   MapBannerEntryList::const_iterator i;
-  for( i = m_entries.begin(); i != m_entries.end(); ++i )
-    (*i)->paint(painter);
+  for(j=0, i = m_entries.begin(); i != m_entries.end(); ++i, j++ ) {
+    // a banner will start to appear if it's in the waiting state
+    // and we give it the start flag
+    // the start flag is given, if a banner is first in the list or
+    // if it's second and the first banner is already disappearing
+    bool start = (j==0);
+    if(j==1)
+      start = (*(i-1))->isDisappearing();
+
+    (*i)->paint(painter, start);
+  }
 }
